BackgroundOverlay class

Inheritance

Constructors

BackgroundOverlay({Key? key, VoidCallback? onTap, required ShapeBorder shape, required Animation<double> animation, required GlobalKey<State<StatefulWidget>> dialKey, required LayerLink layerLink, Color color = Colors.white, double opacity = 0.7})
const

Properties

color → Color
final
dialKey → GlobalKey<State<StatefulWidget>>
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
listenable → Listenable
The Listenable to which this widget is listening.
finalinherited
onTap → VoidCallback?
final
opacity → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder
final

Methods

build(BuildContext context) → Widget
Override this method to build widgets that depend on the state of the listenable (e.g., the current value of the animation).
override
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AnimatedWidget>
Subclasses typically do not override this method.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited